@@ -22,6 +22,11 @@ class SupportsInterval(Protocol):
 
     def __or__(self: SupportsSelf, other: Interval) -> SupportsSelf: ...
 
+    def __ror__(
+        self: SupportsSelf,
+        other: Union[Interval, RealLike, SupportsSelf],
+    ) -> SupportsSelf: ...
+
 
 class Interval:
     _endpoints: tuple[float, ...]
@@ -113,10 +118,19 @@ class Interval:
         return self
 
     @overload
-    def __call__(self: Self, /, *args: Union[Interval, RealLike]) -> Self: ...
+    def __call__(
+        self: Self,
+        /,
+        *args: Union[Interval, RealLike],
+    ) -> Self: ...
 
     @overload
-    def __call__(self: Self, /, *args: Union[Interval, RealLike, SupportsSelf]) -> SupportsSelf: ...
+    def __call__(
+        self: Self,
+        arg: SupportsSelf,
+        /,
+        *args: Union[Interval, RealLike, SupportsSelf],
+    ) -> SupportsSelf: ...
 
     def __call__(self, /, *args):
         result = self[()]
